# The PIL.GdImageFile Module

GdImageFile (class) [#]

  Image plugin for the GD uncompressed format.

  For more information about this class, see The GdImageFile Class.

open(fp, mode="r") [#]
  filename
  mode
  Returns:
  Raises IOError:

## The GdImageFile Class

GdImageFile (class) [#]

  Image plugin for the GD uncompressed format. Note that this format is not supported by the standard Image.open function. To use this plugin, you have to import the GdImageFile module and use the GdImageFile.open function.